@@ -45,6 +45,10 @@ def disabled_function(name):
     Returns a function that cannot be called
     '''
     def disabled(*args, **kwargs):
+        '''
+        A function disabled by the ``future`` module. This function is
+        no longer a builtin in Python 3.
+        '''
         raise NameError('obsolete Python 2 builtin {} is disabled'.format(name))
     return disabled
 
