@@ -30,12 +30,23 @@ and:
             super().append(item)    	# new simpler super() function
 
 range() is a custom class that backports the slicing behaviour from
-Python 3 (from the xrange module by Dan Crosta).
+Python 3 (from the xrange module by Dan Crosta). super() is based on Ryan
+Kelly's magicsuper module. See the docstrings for the
+``future.features.newsuper`` and ``future.features.newrange`` modules for
+more details.
+
 """
 
 from __future__ import division, absolute_import, print_function
 
-from future.features.newrange import range
-from future.features.newsuper import super
+from future import six
+
+if not six.PY3:
+    from future.features.newrange import range
+    from future.features.newsuper import super
+else:
+    import builtins
+    range = builtins.range
+    super = builtins.super
 
 __all__ = ['range', 'super']
