@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
-from future import common_iterators
+from future.common_iterators import *
 
 import unittest
 
@@ -31,4 +31,5 @@ class TestIterators(unittest.TestCase):
         self.assertNotEqual(type(filter(is_odd, a)), list)
         self.assertEqual(list(filter(is_odd, a)), [1, 3, 5, 7, 9])
 
-unittest.main()
+if __name__ == '__main__':
+    unittest.main()
